@@ -15,6 +15,8 @@ use Graphics::Primitive::Driver::Cairo;
 
 use Chart::Clicker::Context;
 
+use Chart::Clicker::Data::DataSet;
+use Chart::Clicker::Data::Series;
 use Chart::Clicker::Decoration::Legend;
 use Chart::Clicker::Decoration::MarkerOverlay;
 use Chart::Clicker::Decoration::Plot;
@@ -23,7 +25,7 @@ use Chart::Clicker::Drawing::ColorAllocator;
 use Carp qw(croak);
 use Scalar::Util qw(refaddr);
 
-our $VERSION = '2.42';
+our $VERSION = '2.44';
 
 has '+background_color' => (
     default => sub {
@@ -56,6 +58,12 @@ has 'contexts' => (
         delete  => 'delete_context'
     }
 );
+has '_data' => (
+    traits => [ 'Hash' ],
+    is => 'rw',
+    isa => 'HashRef[Str]',
+    default => sub { {} }
+);
 has 'datasets' => (
     metaclass => 'Collection::Array',
     is => 'rw',
@@ -193,11 +201,37 @@ sub get_datasets_for_context {
     return \@dses;
 }
 
+sub add_data {
+    my ($self, $name, $data) = @_;
+
+    unless(exists($self->_data->{$name})) {
+        $self->_data->{$name} = [];
+    }
+    push(@{ $self->_data->{$name}}, $data);
+}
+
 override('prepare', sub {
     my ($self, $driver) = @_;
 
     return if $self->prepared;
 
+    if(scalar(keys(%{ $self->_data }))) {
+
+        foreach my $name (keys(%{ $self->_data })) {
+
+            my $ds = Chart::Clicker::Data::DataSet->new;
+            my $vals = $self->_data->{$name};
+            $ds->add_to_series(
+                Chart::Clicker::Data::Series->new(
+                    name    => $name,
+                    keys    => [ 0..scalar(@{ $vals })-1 ],
+                    values  => $vals
+                )
+            );
+            $self->add_to_datasets($ds);
+        }
+    }
+
     unless(scalar(@{ $self->components })) {
         $self->add_component($self->plot, 'c');
 
@@ -246,6 +280,9 @@ override('prepare', sub {
     # them again...
     my %xaxes;
     my %yaxes;
+
+    # A "seen" hash to prevent us from adding multiple renderers for the same
+    # context.
     my %rends;
 
     my $dflt_ctx = $self->get_context('default');
@@ -314,10 +351,13 @@ override('prepare', sub {
         } else {
             $yaxis->range->combine($ds->range);
         }
+
+        # Only add this renderer to the chart if we haven't seen it already.
         unless(exists($rends{$ctx->name})) {
             $rend->context($ctx->name);
             $rend->clicker($self);
             $plot->render_area->add_component($rend, 'c');
+            $rends{$ctx->name} = $rend;
         }
 
         $count++;
@@ -376,21 +416,15 @@ Chart::Clicker - Powerful, extensible charting.
 =head1 SYNOPSIS
 
   use Chart::Clicker;
-  use Chart::Clicker::Data::Series;
-  use Chart::Clicker::Data::DataSet;
 
   my $cc = Chart::Clicker->new;
 
-  my $series = Chart::Clicker::Data::Series->new(
-    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
-    values  => [ 42, 25, 86, 23, 2, 19, 103, 12, 54, 9 ],
-  );
+  my @values = (42, 25, 86, 23, 2, 19, 103, 12, 54, 9);
+  foreach my $v (@values) {
+    $cc->add_data('Sales', $v);
+  }
 
-  my $ds = Chart::Clicker::Data::DataSet->new(series => [ $series ]);
- 
-  $cc->add_to_datasets($ds);
-
-  $cc->write_output('foo.png')
+  $cc->write_output('foo.png');
 
 =head1 DESCRIPTION
 
@@ -406,6 +440,39 @@ For examples of output, see: L<http://www.onemogin.com/clicker/examples>
 
 For code examples see the examples directory of this distribution.
 
+=head1 ADDING DATA
+
+The synopsis shows the simple way to add data.
+
+  my @values = (42, 25, 86, 23, 2, 19, 103, 12, 54, 9);
+  foreach my $v (@values) {
+    $cc->add_data('Sales', $v);
+  }
+
+This is a convenience method provided to make simple cases much simpler. Adding
+multiple Series to a chart is as easy as changing the name argument of
+C<add_data>.  Each unique first argument will result in a separate series.
+
+If you'd like to use the more advanced features of Clicker you'll need to
+shake off this simple method and build Series & DataSets explicitly.
+
+  use Chart::Clicker::Data::Series;
+  use Chart::Clicker::Data::DataSet;
+
+  ...
+
+  my $series = Chart::Clicker::Data::Series->new(
+    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
+    values  => [ 42, 25, 86, 23, 2, 19, 103, 12, 54, 9 ],
+  );
+
+  my $ds = Chart::Clicker::Data::DataSet->new(series => [ $series ]);
+ 
+  $cc->add_to_datasets($ds);
+
+This used to be the only way to add data, but repeated requests to make the
+common case easier resulted in the inclusion of C<add_data>.
+
 =head1 COOKBOOK
 
 Check the cookbook at L<http://www.onemogin.com/clicker/cookbook>
